Runtime abstractions for native and WASM compatibility.
This crate provides abstractions over async runtime functionality to support both native (tokio) and WASM (wasm-bindgen) environments.
Re-exports
pub use cancel::CancellationToken;pub use clock::now;pub use clock::timestamp_secs;pub use sleep::sleep;pub use task::spawn;pub use timeout::timeout;
Modules
Structs
- Elapsed
- Timeout error.
- Instant
- A measurement of a monotonically nondecreasing clock.
Opaque and useful only with
Duration. - System
Time - A measurement of the system clock, useful for talking to external entities like the file system or other processes.
Constants
- UNIX_
EPOCH - An anchor in time which can be used to create new
SystemTimeinstances or learn about where in time aSystemTimelies.